LinkedList

Struct LinkedList 

pub struct LinkedList<T> { /* private fields */ }

Implementations

Source

impl<T> LinkedList<T>

pub const fn new() -> Self

pub fn is_empty(&self) -> bool

pub fn take_all(&self) -> Option<&mut Node<T>>

delete all entries from LinkedList

If list is empty, return NULL, otherwise, delete all entries and return the pointer to the first entry.

pub unsafe fn push(&self, node: &mut Node<T>)

Adds a node to the LinkedList.

Safety

This function is only safe as long as node is guaranteed to get removed from the list before it gets moved or dropped.

pub unsafe fn push_list(&self, node: &mut Node<T>)

Adds a list to the LinkedList.

Safety

This function is only safe as long as node is guaranteed to get removed from the list before it gets moved or dropped.

pub fn remove(&self, node: &mut Node<T>)

Removes a node from the LinkedList.