pub struct LinkedList<T> { /* private fields */ }Implementations
Sourceimpl<T> LinkedList<T>
impl<T> LinkedList<T>
pub const fn new() -> Self
pub fn is_empty(&self) -> bool
Sourcepub fn take_all(&self) -> Option<&mut Node<T>>
pub fn take_all(&self) -> Option<&mut Node<T>>
delete all entries from LinkedList
If list is empty, return NULL, otherwise, delete all entries and return the pointer to the first entry.
Sourcepub unsafe fn push(&self, node: &mut Node<T>)
pub unsafe fn push(&self, node: &mut Node<T>)
Adds a node to the LinkedList.
Safety
This function is only safe as long as node is guaranteed to
get removed from the list before it gets moved or dropped.