pub struct LinkedList<T> { /* private fields */ }

Implementations

Adds a node to the LinkedList. Safety: This function is only safe as long as node is guaranteed to get removed from the list before it gets moved or dropped. In addition to this node may not be added to another other list before it is removed from the current one.

Wake a waiter, and remove it.

Returns false if the pool is empty.